/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id$
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQOFXCONNECT_VERSION_H
#define AQOFXCONNECT_VERSION_H

#define AQOFXCONNECT_VERSION_MAJOR 3
#define AQOFXCONNECT_VERSION_MINOR 5
#define AQOFXCONNECT_VERSION_PATCHLEVEL 1
#define AQOFXCONNECT_VERSION_BUILD 0
#define AQOFXCONNECT_VERSION_TAG "stable"
#define AQOFXCONNECT_VERSION_FULL_STRING "3.5.1.0stable"
#define AQOFXCONNECT_VERSION_STRING "3.5.1"



#endif /* AQOFXCONNECT_VERSION_H */


